@@ -23,16 +23,15 @@
 #include <QString>
 #include <QStringList>
 
-class KTempDir;
+class QTemporaryDir;
 
 class KGpgCaffPrivate : public QObject {
-	Q_OBJECT
 
 	KGpgCaff * const q_ptr;
 	Q_DECLARE_PUBLIC(KGpgCaff)
 	Q_DISABLE_COPY(KGpgCaffPrivate)
 
-	QScopedPointer<KTempDir> m_tempdir;
+	QScopedPointer<QTemporaryDir> m_tempdir;
 	QStringList m_signers;
 	QString m_secringfile;
 	QString m_secringdir; ///< where GnuPG >=2.1 store their secret keyring information
@@ -52,7 +51,7 @@ public:
 	KGpgSignableNode::const_List m_noEncIds;	///< keys without encryption capability that were skipped
 	KGpgSignableNode::const_List m_alreadyIds;	///< ids already signed
 
-private slots:
+private:
 	void slotSigningFinished(int result);
 	void slotDelUidFinished(int result);
 	void slotExportFinished(int result);
