@@ -47,7 +47,7 @@ KGpgAddPhoto::nextLine(const QString &line)
 KGpgTransaction::ts_boolanswer KGpgAddPhoto::boolQuestion(const QString &line)
 {
 	if (line == QLatin1String("photoid.jpeg.size")) {
-		if (KMessageBox::questionYesNo(0, i18n("This image is very large. Use it anyway?"), QString(), KGuiItem(i18n("Use Anyway")), KGuiItem(i18n("Do Not Use"))) == KMessageBox::Yes) {
+        if (KMessageBox::questionYesNo(nullptr, i18n("This image is very large. Use it anyway?"), QString(), KGuiItem(i18n("Use Anyway")), KGuiItem(i18n("Do Not Use"))) == KMessageBox::Yes) {
 			return BA_YES;
 		} else {
 			setSuccess(TS_USER_ABORTED);
