@@ -50,7 +50,7 @@ public:
 	KGpgGenerateKey(QObject *parent, const QString &name, const QString &email, const QString &comment,
 			 const KgpgCore::KgpgKeyAlgo &algorithm, const uint size, const unsigned int expire = 0,
 			 const char expireunit = 'd', const KgpgCore::KgpgSubKeyType capabilities = 0);
-	virtual ~KGpgGenerateKey();
+    ~KGpgGenerateKey() override;
 
 	QString getName() const;
 	QString getEmail() const;
